@@ -2182,7 +2182,7 @@ class SportNumber5(Base):
 
     @classmethod
     def get_numbers(cls):
-        """get numbers [[issue, num1, num2, num3]... ]"""
+        """get numbers [[issue, num1, num2, num3, num4, num5]... ]"""
         session = get_session_sport()
         data = session.query(cls).all()
         session.close()
@@ -2191,7 +2191,7 @@ class SportNumber5(Base):
 
     @classmethod
     def get_one(cls, issue_number: int):
-        """获取对应 issue 的号码列表 [issue, num1, num2, num3]"""
+        """获取对应 issue 的号码列表 [issue, num1, num2, num3, num4, num5]"""
         session = get_session_sport()
         data = session.query(cls).get(issue_number)
         session.close()
@@ -2207,6 +2207,61 @@ class SportNumber5(Base):
         session.close()
         print(f">>> merge kill in kills:{p_issue} - {p_numbers}")
 
+    @classmethod
+    def get_num1(cls, issue_number: int):
+        """获取对应 issue 的号码 num1"""
+        session = get_session_sport()
+        data = session.query(cls).get(issue_number)
+        session.close()
+        return data.num1
+
+    @classmethod
+    def get_num2(cls, issue_number: int):
+        """获取对应 issue 的号码 num2"""
+        session = get_session_sport()
+        data = session.query(cls).get(issue_number)
+        session.close()
+        return data.num2
+
+    @classmethod
+    def get_num3(cls, issue_number: int):
+        """获取对应 issue 的号码 num3"""
+        session = get_session_sport()
+        data = session.query(cls).get(issue_number)
+        session.close()
+        return data.num3
+
+    @classmethod
+    def get_num4(cls, issue_number: int):
+        """获取对应 issue 的号码 num4"""
+        session = get_session_sport()
+        data = session.query(cls).get(issue_number)
+        session.close()
+        return data.num4
+
+    @classmethod
+    def get_num5(cls, issue_number: int):
+        """获取对应 issue 的号码 num5"""
+        session = get_session_sport()
+        data = session.query(cls).get(issue_number)
+        session.close()
+        return data.num5
+
+    @classmethod
+    def get_previous3_issues(cls, issue_now):
+        all_issues = cls.get_issues()
+        all_issues.sort()
+        issue_now = int(issue_now)
+        index_now = all_issues.index(issue_now)
+        return all_issues[index_now - 3: index_now]
+
+    @classmethod
+    def get_next3_issues(cls, issue_now):
+        all_issues = cls.get_issues()
+        issue_now = int(issue_now)
+        index_now = all_issues.index(issue_now)
+        return all_issues[index_now + 1: index_now + 4]
+
 
 class SportFollowX(Base):
     __abstract__ = True
@@ -2248,7 +2303,7 @@ class SportFollowX(Base):
         data = session.query(cls).all()
         result = {}
         for t in data:
-            result[t.issue] = [t.f0, t.f1, t.f2, t.f3, t.f, t.f5, t.f6, t.f7, t.f8, t.f9]
+            result[t.issue] = [t.f0, t.f1, t.f2, t.f3, t.f4, t.f5, t.f6, t.f7, t.f8, t.f9]
         return result
 
     @classmethod
@@ -2257,7 +2312,16 @@ class SportFollowX(Base):
         data = session.query(cls).all()
         result = {}
         for t in data:
-            result[t.issue] = [t.c0, t.c1, t.c2, t.c3, t.c, t.c5, t.c6, t.c7, t.c8, t.c9]
+            result[t.issue] = [t.c0, t.c1, t.c2, t.c3, t.c4, t.c5, t.c6, t.c7, t.c8, t.c9]
+        return result
+
+    @classmethod
+    def get_follow_change_09(cls):
+        session = get_session_sport()
+        data = session.query(cls).all()
+        result = {}
+        for t in data:
+            result[t.issue] = [t.f0, t.f1, t.f2, t.f3, t.f4, t.f5, t.f6, t.f7, t.f8, t.f9, t.c0, t.c1, t.c2, t.c3, t.c4, t.c5, t.c6, t.c7, t.c8, t.c9]
         return result
 
     @classmethod
@@ -2370,3 +2434,115 @@ class SportFollowE(SportFollowX):
         super().__init__()
         self.issue = issue
         self.num = num
+
+
+class SportVerifyX(Base):
+    __abstract__ = True
+
+    inumabc = Column(String(50), primary_key=True)
+    issue = Column(Integer)
+    num = Column(Integer)
+    abc = Column(String(50))
+    result = Column(String(50))
+    score = Column(Float)
+    num1 = Column(Integer)
+    num2 = Column(Integer)
+    num3 = Column(Integer)
+    num4 = Column(Integer)
+    num5 = Column(Integer)
+    verify = Column(String(50))
+
+    @classmethod
+    def add_score(cls, inumabc, issue, num, abc, result, score, channel):
+        """add score
+
+        Args:
+            inumabc (str): issue + num + abc
+            issue (int): issue
+            num (int): num 0 - 9
+            abc (str): 000 - 555
+            result (str): 'n' or 'y'
+            score (float): float result
+            channel (str): 'a' or 'b' or 'c' or 'd' or 'e'
+        """
+        sess = get_session_sport()
+        ins = cls(inumabc)
+        ins.issue = issue
+        ins.num = num
+        ins.abc = abc
+        ins.result = result
+        ins.score = score
+        issues_all = SportNumber5.get_issues()
+        if issue in issues_all:
+            num_channel = {'a': 1, 'b': 2, 'c': 3, 'd': 4, 'e': 5}.get(channel)
+            numbers = SportNumber5.get_one(issue)
+            ins.num1 = numbers[1]
+            ins.num2 = numbers[2]
+            ins.num3 = numbers[3]
+            ins.num4 = numbers[4]
+            ins.num5 = numbers[5]
+            if int(num) == numbers[num_channel]:
+                if result == 'y':
+                    ins.verify = 'y'
+                else:
+                    ins.verify = 'n'
+            else:
+                if result == 'y':
+                    ins.verify = 'n'
+                else:
+                    ins.verify = 'y'
+        else:
+            ins.verify = None
+        sess.merge(ins)
+        sess.commit()
+        sess.close()
+        print(
+            f">>> {cls.__tablename__}: add score channel:{channel}: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
+
+
+class SportVerifyA(SportVerifyX):
+    __tablename__ = "verifya"
+
+    def __init__(self, inumabc) -> None:
+        super().__init__()
+        self.inumabc = inumabc
+
+
+class SportVerifyB(SportVerifyX):
+    __tablename__ = "verifyb"
+
+    def __init__(self, inumabc) -> None:
+        super().__init__()
+        self.inumabc = inumabc
+
+
+class SportVerifyC(SportVerifyX):
+    __tablename__ = "verifyc"
+
+    def __init__(self, inumabc) -> None:
+        super().__init__()
+        self.inumabc = inumabc
+
+
+class SportVerifyD(SportVerifyX):
+    __tablename__ = "verifyd"
+
+    def __init__(self, inumabc) -> None:
+        super().__init__()
+        self.inumabc = inumabc
+
+
+class SportVerifyE(SportVerifyX):
+    __tablename__ = "verifye"
+
+    def __init__(self, inumabc) -> None:
+        super().__init__()
+        self.inumabc = inumabc
+
+
+if __name__ == "__main__":
+    # generate tables
+    # engine = create_engine("mysql+pymysql://root:Wangchenyu2012@localhost:3306/p3")
+    # Base.metadata.create_all(engine)
+    pass
+    # SportVerifyA.add_score('20212993123', 2021299, '3', '235', 'y', 0.56, 'a')
