@@ -2793,7 +2793,7 @@ class WelfareVerify(Base):
         sess.commit()
         sess.close()
         print(
-            f">>> add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
+            f">>> {cls.__tablename__}: add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
 
 
 class WelfareVerifyA(Base):
@@ -2820,13 +2820,13 @@ class WelfareVerifyA(Base):
         self.score = score
 
     @classmethod
-    def add_score(cls, inumabc, issue, num, abc, result, score):
+    def add_score(cls, inumabc, issue: int, num, abc, result, score: float):
         sess = get_session_welfare()
         ins = cls(inumabc, issue, num, abc, result, score)
         issues_all = WelfareNumber.get_issues()
-        if issue in issues_all:
-            numbers = WelfareNumber.get_one(issue)
-            if int(num) in numbers[1:]:
+        if int(issue) in issues_all:
+            number = sess.query(WelfareNumber).get(issue).num1
+            if int(num) == number:
                 if result == 'y':
                     ins.verify = 'y'
                 else:
@@ -2842,7 +2842,7 @@ class WelfareVerifyA(Base):
         sess.commit()
         sess.close()
         print(
-            f">>> add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
+            f">>> {cls.__tablename__} add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
 
 
 class WelfareVerifyB(Base):
@@ -2869,13 +2869,13 @@ class WelfareVerifyB(Base):
         self.score = score
 
     @classmethod
-    def add_score(cls, inumabc, issue, num, abc, result, score):
+    def add_score(cls, inumabc, issue: int, num, abc, result, score: float):
         sess = get_session_welfare()
         ins = cls(inumabc, issue, num, abc, result, score)
         issues_all = WelfareNumber.get_issues()
-        if issue in issues_all:
-            numbers = WelfareNumber.get_one(issue)
-            if int(num) in numbers[1:]:
+        if int(issue) in issues_all:
+            number = sess.query(WelfareNumber).get(issue).num2
+            if int(num) == number:
                 if result == 'y':
                     ins.verify = 'y'
                 else:
@@ -2891,7 +2891,7 @@ class WelfareVerifyB(Base):
         sess.commit()
         sess.close()
         print(
-            f">>> add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
+            f">>> {cls.__tablename__} add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
 
 
 class WelfareVerifyC(Base):
@@ -2918,13 +2918,13 @@ class WelfareVerifyC(Base):
         self.score = score
 
     @classmethod
-    def add_score(cls, inumabc, issue, num, abc, result, score):
+    def add_score(cls, inumabc, issue: int, num, abc, result, score: float):
         sess = get_session_welfare()
         ins = cls(inumabc, issue, num, abc, result, score)
         issues_all = WelfareNumber.get_issues()
-        if issue in issues_all:
-            numbers = WelfareNumber.get_one(issue)
-            if int(num) in numbers[1:]:
+        if int(issue) in issues_all:
+            number = sess.query(WelfareNumber).get(issue).num3
+            if int(num) == number:
                 if result == 'y':
                     ins.verify = 'y'
                 else:
@@ -2940,7 +2940,7 @@ class WelfareVerifyC(Base):
         sess.commit()
         sess.close()
         print(
-            f">>> add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
+            f">>> {cls.__tablename__} add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
 
 
 class WelfareFollowX(Base):
